# Tests for ob_arch_is_concerned()
#
# Copyright (C) 2012, 2014, 2018, 2019 Patrick McDermott
#
# This file is part of opkbuild.
#
# opkbuild is free software: you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# opkbuild is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with opkbuild.  If not, see <http://www.gnu.org/licenses/>.

set -eu

. "${TOP_SRCDIR}/tests/aux/tap-functions.sh"
. "${TOP_BUILDDIR}/lib/libopkbuild.${SHSOEXT}.${LIBOPKBUILD_SHSOVERSION}"

plan_ 18

# Architecture: all

command_ok_ \
	'HOST "amd64-linux-glibc" DOES NOT MATCH ARCH "all"' -- \
	not ob_arch_is_concerned \
	'amd64-linux-glibc' \
	'all'

command_ok_ \
	'HOST "i686-linux-glibc" DOES NOT MATCH ARCH "all"' -- \
	not ob_arch_is_concerned \
	'i686-linux-glibc' \
	'all'

command_ok_ \
	'HOST "all" DOES MATCH ARCH "all"' -- \
	ob_arch_is_concerned \
	'all' \
	'all'

# Architecture: any

command_ok_ \
	'HOST "amd64-linux-glibc" DOES MATCH ARCH "any"' -- \
	ob_arch_is_concerned \
	'amd64-linux-glibc' \
	'any'

command_ok_ \
	'HOST "i686-linux-glibc" DOES MATCH ARCH "any"' -- \
	ob_arch_is_concerned \
	'i686-linux-glibc' \
	'any'

command_ok_ \
	'HOST "all" DOES NOT MATCH ARCH "any"' -- \
	not ob_arch_is_concerned \
	'all' \
	'any'

# Architecture: amd64-linux-glibc

command_ok_ \
	'HOST "amd64-linux-glibc" DOES MATCH ARCH "amd64-linux-glibc"' -- \
	ob_arch_is_concerned \
	'amd64-linux-glibc' \
	'amd64-linux-glibc'

command_ok_ \
	'HOST "i686-linux-glibc" DOES NOT MATCH ARCH "amd64-linux-glibc"' -- \
	not ob_arch_is_concerned \
	'i686-linux-glibc' \
	'amd64-linux-glibc'

command_ok_ \
	'HOST "all" DOES NOT MATCH ARCH "amd64-linux-glibc"' -- \
	not ob_arch_is_concerned \
	'all' \
	'amd64-linux-glibc'

# Architecture: !amd64-linux-glibc

command_ok_ \
	'HOST "amd64-linux-glibc" DOES NOT MATCH ARCH "!amd64-linux-glibc"' -- \
	not ob_arch_is_concerned \
	'amd64-linux-glibc' \
	'!amd64-linux-glibc'

command_ok_ \
	'HOST "i686-linux-glibc" DOES MATCH ARCH "!amd64-linux-glibc"' -- \
	ob_arch_is_concerned \
	'i686-linux-glibc' \
	'!amd64-linux-glibc'

command_ok_ \
	'HOST "all" DOES NOT MATCH ARCH "!amd64-linux-glibc"' -- \
	not ob_arch_is_concerned \
	'all' \
	'!amd64-linux-glibc'

# Architecture: amd64-any-any

command_ok_ \
	'HOST "amd64-linux-glibc" DOES NOT MATCH ARCH "amd64-any-any"' -- \
	ob_arch_is_concerned \
	'amd64-linux-glibc' \
	'amd64-any-any'

command_ok_ \
	'HOST "i686-linux-glibc" DOES MATCH ARCH "amd64-any-any"' -- \
	not ob_arch_is_concerned \
	'i686-linux-glibc' \
	'amd64-any-any'

command_ok_ \
	'HOST "all" DOES NOT MATCH ARCH "amd64-any-any"' -- \
	not ob_arch_is_concerned \
	'all' \
	'amd64-any-any'

# Architecture: cortexa8-any-any i686-any-any

command_ok_ \
	'HOST "amd64-linux-glibc" DOES NOT MATCH ARCH '$(: \
		)'"cortexa8-any-any i686-any-any"' -- \
	not ob_arch_is_concerned \
	'amd64-linux-glibc' \
	'cortexa8-any-any i686-any-any'

command_ok_ \
	'HOST "i686-linux-glibc" DOES MATCH ARCH '$(: \
		)'"cortexa8-any-any i686-any-any"' -- \
	ob_arch_is_concerned \
	'i686-linux-glibc' \
	'cortexa8-any-any i686-any-any'

command_ok_ \
	'HOST "all" DOES NOT MATCH ARCH "cortexa8-any-any i686-any-any"' -- \
	not ob_arch_is_concerned \
	'all' \
	'cortexa8-any-any i686-any-any'
